@@ -478,11 +478,11 @@ tab_width (Buffer * bp)
 astr
 copy_text_block (Point pt, size_t size)
 {
-  Line *lp;
-  astr as = astr_substr (get_line_text (pt.p), pt.o, astr_len (get_line_text (pt.p)) - pt.o);
+  Line * lp = pt.p;
+  astr as = astr_substr (get_line_text (lp), pt.o, astr_len (get_line_text (lp)) - pt.o);
 
   astr_cat_char (as, '\n');
-  for (lp = get_line_next (pt.p); astr_len (as) < size; lp = get_line_next (lp))
+  for (lp = get_line_next (lp); astr_len (as) < size; lp = get_line_next (lp))
     {
       astr_cat (as, get_line_text (lp));
       astr_cat_char (as, '\n');
@@ -505,66 +505,55 @@ create_scratch_buffer (void)
 
 /*
  * Remove the specified buffer from the buffer list and deallocate
- * its space.  Avoid killing the sole buffers and creates the scratch
- * buffer when required.
+ * its space.  Recreate the scratch buffer when required.
  */
 void
 kill_buffer (Buffer * kill_bp)
 {
-  Buffer *next_bp;
+  Buffer *bp, *next_bp;
+  Window *wp;
 
   if (get_buffer_next (kill_bp) != NULL)
     next_bp = get_buffer_next (kill_bp);
   else
-    next_bp = head_bp;
+    next_bp = (head_bp == kill_bp) ? NULL : head_bp;
 
-  if (next_bp == kill_bp) /* Only one buffer. */
+  /* Search for windows displaying the buffer to kill. */
+  for (wp = head_wp; wp != NULL; wp = get_window_next (wp))
+    if (get_window_bp (wp) == kill_bp)
+      {
+        set_window_bp (wp, next_bp);
+        set_window_topdelta (wp, 0);
+        set_window_saved_pt (wp, NULL); /* The old marker will be freed. */
+      }
+
+  /* Remove the buffer from the buffer list. */
+  if (cur_bp == kill_bp)
+    cur_bp = next_bp;
+  if (head_bp == kill_bp)
+    head_bp = get_buffer_next (head_bp);
+  for (bp = head_bp; bp != NULL && get_buffer_next (bp) != NULL; bp = get_buffer_next (bp))
+    if (get_buffer_next (bp) == kill_bp)
+      {
+        set_buffer_next (bp, get_buffer_next (get_buffer_next (bp)));
+        break;
+      }
+
+  free_buffer (kill_bp);
+
+  /* If no buffers left, recreate scratch buffer and point windows at
+     it. */
+  if (next_bp == NULL)
     {
-      Window *wp, *next_wp;
-
-      assert (cur_bp == kill_bp);
-      free_buffer (cur_bp);
-      head_bp = NULL;
-
-      /* Close all the windows that display this buffer. */
-      for (wp = head_wp; wp != NULL; wp = next_wp)
-        {
-          next_wp = get_window_next (wp);
-          if (get_window_bp (wp) == cur_bp)
-            delete_window (wp);
-        }
-
-      create_scratch_window ();
-    }
-  else
-    {
-      Buffer *bp;
-      Window *wp;
-
-      /* Search for windows displaying the buffer to kill. */
+      cur_bp = head_bp = next_bp = create_scratch_buffer ();
       for (wp = head_wp; wp != NULL; wp = get_window_next (wp))
-        if (get_window_bp (wp) == kill_bp)
-          {
-            set_window_bp (wp, next_bp);
-            set_window_topdelta (wp, 0);
-            set_window_saved_pt (wp, NULL);	/* The marker will be freed. */
-          }
-
-      /* Remove the buffer from the buffer list. */
-      cur_bp = next_bp;
-      if (head_bp == kill_bp)
-        head_bp = get_buffer_next (head_bp);
-      for (bp = head_bp; get_buffer_next (bp) != NULL; bp = get_buffer_next (bp))
-        if (get_buffer_next (bp) == kill_bp)
-          {
-            set_buffer_next (bp, get_buffer_next (get_buffer_next (bp)));
-            break;
-          }
-
-      free_buffer (kill_bp);
-
-      thisflag |= FLAG_NEED_RESYNC;
+        set_window_bp (wp, head_bp);
     }
+
+  /* Resync windows that need it. */
+  for (wp = head_wp; wp != NULL; wp = get_window_next (wp))
+    if (get_window_bp (wp) == next_bp)
+      resync_redisplay (wp);
 }
 
 DEFUN_ARGS ("kill-buffer", kill_buffer,
