@@ -188,7 +188,7 @@ goto_linep (Line * lp)
 {
   Point pt;
   set_buffer_pt (cur_bp, point_min ());
-  resync_redisplay ();
+  resync_redisplay (cur_wp);
   for (pt = get_buffer_pt (cur_bp); pt.p != lp; pt = get_buffer_pt (cur_bp))
     next_line ();
 }
@@ -515,7 +515,7 @@ isearch (int dir, int regexp)
         last = true;
 
       if (thisflag & FLAG_NEED_RESYNC)
-        resync_redisplay ();
+        resync_redisplay (cur_wp);
     }
 
   /* done */
@@ -619,7 +619,7 @@ what to do with it.
       if (!noask)
         {
           if (thisflag & FLAG_NEED_RESYNC)
-            resync_redisplay ();
+            resync_redisplay (cur_wp);
           for (;;)
             {
               minibuf_write
@@ -662,7 +662,7 @@ what to do with it.
   free (repl);
 
   if (thisflag & FLAG_NEED_RESYNC)
-    resync_redisplay ();
+    resync_redisplay (cur_wp);
 
   if (ok)
     minibuf_write ("Replaced %d occurrences", count);
